import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-elisa-updater',
    version='0.1', 
    description='Elisa plugins updater',
    long_description='Elisa plugins updater',
    license='UNKNOWN', 
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    keywords='',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.png', '*.mo', '*.po']},
    entry_points="""\
    [elisa.core.components.resource_provider]
    UpdaterResourceProvider = elisa.plugins.elisa_updater.resource_provider:UpdaterResourceProvider
    """,
    cmdclass=cmdclass)
